@@ -12,7 +12,7 @@
 class LibraryItem;
 class IoPin;
 
-class MAINMODULE_EXPORT OpAmp : public Component, public eElement
+class OpAmp : public Component, public eElement
 {
     public:
         OpAmp( QString type, QString id );
@@ -51,7 +51,7 @@ class MAINMODULE_EXPORT OpAmp : public Component, public eElement
         virtual void slotProperties() override;
 
     protected:
-        void udtProperties();
+        void updtProperties();
 
         bool m_powerPins;
         bool m_switchPins;
