@@ -40,13 +40,15 @@ ADC::ADC( QString type, QString id )
     m_maxVolt = 5;
 
     addPropGroup( { tr("Main"), {
-new IntProp <ADC>("Num_Bits", tr("Size"),"_Bits", this
+new IntProp <ADC>("Num_Bits", tr("Size"),"_bits", this
                  , &ADC::numOuts, &ADC::setNumOutputs, propNoCopy,"uint" ),
 
-new DoubProp<ADC>("Vref", tr("Reference Voltage"),"V", this, &ADC::maxVolt, &ADC::setMaxVolt ),
+new DoubProp<ADC>("Vref", tr("Reference Voltage"),"V"
+                 , this, &ADC::maxVolt, &ADC::setMaxVolt ),
     },groupNoCopy} );
+
     addPropGroup( { tr("Electric"), IoComponent::outputProps()+IoComponent::outputType(),0 } );
-    addPropGroup( { tr("Edges")   , IoComponent::edgeProps()                            ,0 } );
+    addPropGroup( { tr("Timing")  , IoComponent::edgeProps()                            ,0 } );
 }
 ADC::~ADC(){}
 
@@ -60,6 +62,7 @@ void ADC::voltChanged()
 {
     double volt = m_inPin[0]->getVoltage();
     m_nextOutVal = volt*m_maxValue/m_maxVolt+0.1;
+    if( m_nextOutVal > m_maxValue ) m_nextOutVal = m_maxValue;
     LogicComponent::scheduleOutPuts( this );
 }
 
