@@ -31,15 +31,15 @@ AndGate::AndGate( QString type, QString id )
 {
     addPropGroup( { tr("Electric"), IoComponent::inputProps()
 +QList<ComProperty*>({
-new BoolProp<AndGate>( "Invert_Inputs", tr("Invert Inputs"),"", this
-                     , &AndGate::invertInps, &AndGate::setInvertInps, propNoCopy ),
+new BoolProp<AndGate>("Invert_Inputs", tr("Invert Inputs"),""
+                     , this, &AndGate::invertInps, &AndGate::setInvertInps, propNoCopy ),
 
-new IntProp <AndGate>( "Num_Inputs"   , tr("Input Size")   ,"_Inputs", this
-                     , &AndGate::numInps, &AndGate::setNumInputs, propNoCopy,"uint" )
+new IntProp <AndGate>("Num_Inputs", tr("Input Size"),"_Inputs"
+                     , this, &AndGate::numInps, &AndGate::setNumInputs, propNoCopy,"uint" )
                     })
-+IoComponent::outputProps()+IoComponent::outputType(),0 } );
++Gate::outputProps()+IoComponent::outputType(),0 } );
 
-    addPropGroup( { tr("Edges"), Gate::edgeProps(),0 } );
+    addPropGroup( { tr("Timing"), IoComponent::edgeProps(),0 } );
 
     removeProperty("pd_n");
 }
@@ -66,4 +66,6 @@ void AndGate::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidge
 {
     Component::paint( p, option, widget );
     p->drawChord( -27, m_area.y(), 36, m_area.height(), -1440/*-16*90*/, 2880/*16*180*/ );
+
+    Component::paintSelected( p );
 }
