@@ -6,26 +6,28 @@
 #include "ampmeter.h"
 #include "itemlibrary.h"
 
-Component* Amperimeter::construct( QObject* parent, QString type, QString id )
-{ return new Amperimeter( parent, type, id ); }
+#define tr(str) simulideTr("Amperimeter",str)
+
+Component* Amperimeter::construct( QString type, QString id )
+{ return new Amperimeter( type, id ); }
 
 LibraryItem* Amperimeter::libraryItem()
 {
     return new LibraryItem(
-        QCoreApplication::translate("Meters","Ampmeter"),
+        tr("Ampmeter"),
         "Meters",
         "amperimeter.png",
         "Amperimeter",
         Amperimeter::construct);
 }
 
-Amperimeter::Amperimeter( QObject* parent, QString type, QString id )
-           : Meter( parent, type, id )
+Amperimeter::Amperimeter( QString type, QString id )
+           : Meter( type, id )
 {
     m_unit = "A";
     m_dispValue = 0;
     setRes( 1e-6 );
-    m_display.setText( " 0.000\n A");
+    m_display.setText(" 0.000\n A");
 }
 Amperimeter::~Amperimeter(){}
 
