@@ -16,13 +16,13 @@
 class LibraryItem;
 class IoPin;
 
-class MAINMODULE_EXPORT Ssd1306 : public Component, public TwiModule
+class Ssd1306 : public Component, public TwiModule
 {
     public:
-        Ssd1306( QObject* parent, QString type, QString id );
+        Ssd1306( QString type, QString id );
         ~Ssd1306();
 
- static Component* construct( QObject* parent, QString type, QString id );
+ static Component* construct( QString type, QString id );
  static LibraryItem* libraryItem();
 
         enum dispColor {
@@ -39,10 +39,12 @@ class MAINMODULE_EXPORT Ssd1306 : public Component, public TwiModule
         int height() { return m_height; }
         void setHeight( int h );
 
+        bool imgRotated() { return m_rotate; }
+        void setImgRotated( bool r ) { m_rotate = r; }
+
         virtual void initialize() override;
         virtual void stamp() override;
         virtual void updateStep() override;
-        virtual void remove() override;
 
         virtual void readByte() override;
         virtual void I2Cstop() override;
@@ -52,28 +54,26 @@ class MAINMODULE_EXPORT Ssd1306 : public Component, public TwiModule
     protected:
         void writeData();
         void proccessCommand();
-        void clearLcd();
         void incrementPointer();
         void reset();
         void clearDDRAM();
         void updateSize();
-        
-        QImage* m_pdisplayImg;    //Visual representation of the LCD
+
         dispColor m_dColor;
 
         unsigned char m_aDispRam[128][8]; //128x64 DDRAM
 
-        int m_cdr;                // Clock Divide Ratio
-        int m_mr;                 // Multiplex Ratio
-        int m_fosc;               // Oscillator Frequency
-        int m_frm;                // Frame Frequency
+        int m_cdr;       // Clock Divide Ratio
+        int m_mr;        // Multiplex Ratio
+        int m_fosc;      // Oscillator Frequency
+        int m_frm;       // Frame Frequency
 
         int m_width;
         int m_height;
         int m_rows;
 
-        int m_addrX;              // X RAM address
-        int m_addrY;              // Y RAM address
+        int m_addrX;     // X RAM address
+        int m_addrY;     // Y RAM address
         int m_startX;
         int m_endX;
         int m_startY;
@@ -94,6 +94,8 @@ class MAINMODULE_EXPORT Ssd1306 : public Component, public TwiModule
         bool m_dispOn;
         bool m_dispFull;
         bool m_dispInv;
+        bool m_scanInv;
+        bool m_rotate;
 
         //bool m_reset;
         bool m_command;
@@ -108,6 +110,8 @@ class MAINMODULE_EXPORT Ssd1306 : public Component, public TwiModule
         //Pin m_pinRst;
         //Pin m_pinDC;
         //Pin m_pinCS;
+
+        QColor m_foreground;
 };
 
 #endif
