@@ -40,6 +40,9 @@ ResistorDip::ResistorDip( QString type, QString id )
            : Component( type, id )
            , eElement( id )
 {
+    m_pullUp = false;
+    m_puVolt = 5;
+
     m_size = 0;
     setSize( 8 );
 
@@ -47,16 +50,17 @@ ResistorDip::ResistorDip( QString type, QString id )
     setValLabelPos( 5,-26, 90 );
     m_valLabel->setAcceptedMouseButtons( 0 );
 
-    m_pullUp = false;
-    m_puVolt = 5;
+    QFont font = m_valLabel->font();
+    font.setPixelSize( 6 );
+    m_valLabel->setFont( font );
 
     Simulator::self()->addToUpdateList( this );
 
     addPropGroup( { tr("Main"), {
-new DoubProp<ResistorDip>( "Resistance", tr("Resistance"),"Ω"       , this, &ResistorDip::getRes, &ResistorDip::setRes ),
-new IntProp <ResistorDip>( "Size"      , tr("Size")      ,"_Resist.", this, &ResistorDip::size,   &ResistorDip::setSize, propNoCopy,"uint" ),
-new BoolProp<ResistorDip>( "PullUp"    , tr("Pullup")    ,""        , this, &ResistorDip::pullUp, &ResistorDip::setPullUp ),
-new DoubProp<ResistorDip>( "PuVolt", tr("Pullup Voltage"),"V"       , this, &ResistorDip::puVolt, &ResistorDip::setPuVolt ),
+new DoubProp<ResistorDip>( "Resistance", tr("Resistance"),"Ω", this, &ResistorDip::getRes, &ResistorDip::setRes ),
+new IntProp <ResistorDip>( "Size"      , tr("Size")      ,"" , this, &ResistorDip::size,   &ResistorDip::setSize, propNoCopy,"uint" ),
+new BoolProp<ResistorDip>( "PullUp"    , tr("Pullup")    ,"" , this, &ResistorDip::pullUp, &ResistorDip::setPullUp ),
+new DoubProp<ResistorDip>( "PuVolt", tr("Pullup Voltage"),"V", this, &ResistorDip::puVolt, &ResistorDip::setPuVolt ),
     },0 } );
 
     setShowProp("Resistance");
@@ -103,6 +107,8 @@ void ResistorDip::createResistors( int c )
         m_resistor[i]->setEpin( 0, m_pin[index] );
 
         m_pin[index+1] = new Pin( 0, QPoint( 16,-32+8+i*8 ), reid+"-ePin"+QString::number(index+1), 0, this);
+        m_pin[index+1]->setEnabled( !m_pullUp ); //
+        m_pin[index+1]->setVisible( !m_pullUp ); //
         m_resistor[i]->setEpin( 1, m_pin[index+1] );
 }   }
 
@@ -111,13 +117,8 @@ void ResistorDip::deleteResistors( int d )
     if( d > m_size ) d = m_size;
     int start = m_size-d;
 
-    for( int i=start*2; i<m_size*2; ++i )
-    {
-        m_pin[i]->removeConnector();
-        m_signalPin.removeAll( m_pin[i] );
-        delete m_pin[i];
-    }
-    for( int i=start; i<m_size; i++ ) delete m_resistor[i];
+    for( int i=start*2; i<m_size*2; ++i ) deletePin( m_pin[i] );
+    for( int i=start;   i<m_size;   ++i ) delete m_resistor[i];
     m_size = m_size-d;
     m_resistor.resize( m_size );
     m_pin.resize( m_size*2 );
@@ -151,7 +152,7 @@ void ResistorDip::setPullUp( bool p )
 
     if( Simulator::self()->isRunning() )  CircuitWidget::self()->powerCircOff();
 
-    if( m_propDialog ) m_propDialog->showProp("PuVolt", p );
+    updtProperties();
 
     for( int i=0; i<m_size; i++ )
     {
@@ -163,10 +164,17 @@ void ResistorDip::setPullUp( bool p )
     }
 }
 
+void ResistorDip::updtProperties()
+{
+    if( !m_propDialog ) return;
+    m_propDialog->showProp("PuVolt", m_pullUp );
+    m_propDialog->adjustWidgets();
+}
+
 void ResistorDip::slotProperties()
 {
     Component::slotProperties();
-    m_propDialog->showProp("PuVolt", m_pullUp );
+    updtProperties();
 }
 
 void ResistorDip::remove()
@@ -175,8 +183,10 @@ void ResistorDip::remove()
     Component::remove();
 }
 
-void ResistorDip::paint( QPainter *p, const QStyleOptionGraphicsItem *option, QWidget *widget )
+void ResistorDip::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget )
 {
     Component::paint( p, option, widget );
     p->drawRoundRect( QRect( -9, -28, 18, m_size*8 ), 2, 2 );
+
+    Component::paintSelected( p );
 }
