@@ -11,13 +11,13 @@
 
 class LibraryItem;
 
-class MAINMODULE_EXPORT Csource : public Component, public eResistor
+class Csource : public Component, public eResistor
 {
     public:
-        Csource( QObject* parent, QString type, QString id );
+        Csource( QString type, QString id );
         ~Csource();
 
- static Component* construct( QObject* parent, QString type, QString id );
+ static Component* construct( QString type, QString id );
  static LibraryItem* libraryItem();
 
         virtual void stamp() override;
@@ -44,6 +44,7 @@ class MAINMODULE_EXPORT Csource : public Component, public eResistor
 
         void setVoltage( double v );
 
+        virtual void setLinked( bool l ) override;
         virtual void setLinkedValue( double v, int i=0 ) override;
 
         //virtual QPainterPath shape() const;
@@ -53,12 +54,14 @@ class MAINMODULE_EXPORT Csource : public Component, public eResistor
         virtual void slotProperties() override;
 
     private:
-        void udtProperties();
+        void updtProperties();
 
         double m_volt;
         double m_curr;
         double m_gain;
 
+        double m_lastCurr;
+
         bool m_controlPins;
         bool m_currSource;
         bool m_currControl;
