@@ -48,6 +48,8 @@ Relay::Relay( QString type, QString id )
 
     m_pin[0] = m_inductor->getPin( 0 );
     m_pin[1] = m_inductor->getPin( 1 );
+    addSignalPin( m_pin[0] );
+    addSignalPin( m_pin[1] );
 
     m_trigCurrent = 0.02;
     m_relCurrent  = 0.01;
@@ -58,18 +60,18 @@ Relay::Relay( QString type, QString id )
     SetupSwitches( 1, 1 );
 
     addPropGroup( { tr("Main"), {
-new BoolProp<Relay>( "Norm_Close", tr("Normally Closed"),""      , this, &Relay::nClose, &Relay::setNClose ),
-new BoolProp<Relay>( "DT"        , tr("Double Throw")   ,""      , this, &Relay::dt,     &Relay::setDt, propNoCopy ),
-new IntProp <Relay>( "Poles"     , tr("Poles")          ,"_Poles", this, &Relay::poles,  &Relay::setPoles, propNoCopy,"uint" ),
+new BoolProp<Relay>( "Norm_Close", tr("Normally Closed"),"", this, &Relay::nClose, &Relay::setNClose ),
+new BoolProp<Relay>( "DT"        , tr("Double Throw")   ,"", this, &Relay::dt,     &Relay::setDt, propNoCopy ),
+new IntProp <Relay>( "Poles"     , tr("Poles")          ,"", this, &Relay::poles,  &Relay::setPoles, propNoCopy,"uint" ),
     }, 0} );
     addPropGroup( { tr("Electric"), {
 new DoubProp<Relay>( "IOn" , tr("IOn") ,"A", this, &Relay::iTrig, &Relay::setITrig),
 new DoubProp<Relay>( "IOff", tr("IOff"),"A", this, &Relay::iRel,  &Relay::setIRel )
     }, 0} );
     addPropGroup( { tr("Coil"), {
-new DoubProp<Inductor>( "Inductance", tr("Inductance"),"H", m_inductor, &Inductor::value , &Inductor::setValue ),
-new DoubProp<Inductor>( "Rcoil"     , tr("Resistance"),"Ω", m_inductor, &Inductor::resist, &Inductor::setResist),
-new IntProp <Inductor>( "AutoStep"  , tr("Auto Step") , "_Steps", m_inductor, &Inductor::autoStep, &Inductor::setAutoStep,0,"uint" )
+new DoubProp<Inductor>("Inductance", tr("Inductance"),"H", m_inductor, &Inductor::value , &Inductor::setValue ),
+new DoubProp<Inductor>("Rcoil"     , tr("Resistance"),"Ω", m_inductor, &Inductor::resist, &Inductor::setResist),
+new DoubProp<Inductor>("ReaStep", tr("Reactive Step"),"ns",m_inductor, &Inductor::reaStep, &Inductor::setReaStep,0,"uint" )
     }, 0} );
 }
 Relay::~Relay(){}
