@@ -96,7 +96,7 @@ void Node::joinConns( int c0, int c1 )
     if( pin1->conPin() != pin0 )
     {
         Connector* con = new Connector( "Connector", "Connector-"+Circuit::self()->newConnectorId(), pin0->conPin() );
-        Circuit::self()->conList()->insert( con );
+        Circuit::self()->conList()->append( con );
 
         QStringList list0 = con0->pointList();
         QStringList list1 = con1->pointList();
@@ -152,4 +152,6 @@ void Node::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget*
     
     if( m_isBus ) p->drawEllipse( QPointF(0,0), 1.8, 1.8  );
     else          p->drawEllipse( QPointF(0,0), 1.4, 1.4 );
+
+    Component::paintSelected( p );
 }
