@@ -4,11 +4,17 @@
  ***( see copyright.txt file at root folder )*******************************/
 
 #include "labelval.h"
+#include "mainwindow.h"
 
 LabelVal::LabelVal( QWidget* parent )
         : QWidget( parent )
 {
     setupUi( this );
+
+    //float scale = MainWindow::self()->fontScale();
+    //QFont font = label->font();
+    //font.setPixelSize( 11.0*scale );
+    //label->setFont( font );
 }
 
 void LabelVal::setLabelVal( QString caption )
