@@ -10,6 +10,7 @@
 BoardSubc::BoardSubc( QString type, QString id )
          : SubCircuit( type, id )
 {
+    m_graphical = true;
     m_subcType = Chip::Board;
     //m_shield = NULL;
 }
@@ -20,12 +21,12 @@ void BoardSubc::attachShield( ShieldSubc* shield )
     if( !m_shields.contains( shield ) ) m_shields.append( shield );
 }
 
-void BoardSubc::remove()
+/*void BoardSubc::remove()
 {
     for( ShieldSubc* shield : m_shields ) // there is a shield attached to this
     {
         shield->setBoard( NULL );
-        Circuit::self()->removeComp( shield );
+        //Circuit::self()->removeComp( shield );
     }
     SubCircuit::remove();
-}
+}*/
