@@ -64,7 +64,7 @@ Chip::Chip( QString type, QString id )
     m_label.setFont( f );
     m_label.setDefaultTextColor( QColor( 125, 125, 110 ) );
     m_label.setAcceptedMouseButtons( 0 );
-    m_label.setRotation( -90 );
+    m_label.setRotation(-90 );
     m_label.setVisible( true );
     
     setLabelPos( m_area.x(), m_area.y()-20, 0);
@@ -97,34 +97,8 @@ void Chip::initChip()
     QDomDocument domDoc = fileToDomDoc( fileNameAbs, "Chip::initChip" );
     QDomElement   root  = domDoc.documentElement();
 
-    if( root.tagName() == "packageB" )
-    {
-        if( m_pkgeFile.endsWith( "_LS.package" )) m_isLS = true;
-        else                                      m_isLS = false;
-
-        if( m_isLS ) m_color = m_lsColor;
-        else         m_color = m_icColor;
-
-        m_width   = root.attribute( "width" ).toInt();
-        m_height  = root.attribute( "height" ).toInt();
-        m_area = QRect( 0, 0, 8*m_width, 8*m_height );
-
-        for( Pin* pin : m_unusedPins ) if( pin ) deletePin( pin );
-        m_unusedPins.clear();
-        m_ePin.clear();
-        m_pin.clear();
-
-        if( root.hasAttribute("type") ) setSubcTypeStr( root.attribute("type") );
-        if( root.hasAttribute("background") ) setBackground( root.attribute("background") );
-        if( m_subcType >= Board ) setTransformOriginPoint( toGrid( boundingRect().center()) );
-        if( root.hasAttribute("name"))
-        {
-            QString name = root.attribute("name");
-            if( name.toLower() != "package" ) m_name = name;
-        }
-        initPackage( root );
-        setName( m_name );
-    }else{
+    if( root.tagName() == "packageB" ) initPackage( root );
+    else{
         qDebug() <<"Chip::initChip"<<"Error: Not valid Package file:\n"<< m_pkgeFile;
         m_error = 3;
         return;
@@ -143,6 +117,30 @@ void Chip::setName( QString name )
 
 void Chip::initPackage( QDomElement root )
 {
+    if( m_pkgeFile.endsWith( "_LS.package" )) m_isLS = true;
+    else                                      m_isLS = false;
+
+    if( m_isLS ) m_color = m_lsColor;
+    else         m_color = m_icColor;
+
+    m_width   = root.attribute( "width" ).toInt();
+    m_height  = root.attribute( "height" ).toInt();
+    m_area = QRect( 0, 0, 8*m_width, 8*m_height );
+
+    for( Pin* pin : m_unusedPins ) if( pin ) deletePin( pin );
+    m_unusedPins.clear();
+    m_ePin.clear();
+    m_pin.clear();
+
+    if( root.hasAttribute("type") ) setSubcTypeStr( root.attribute("type") );
+    if( root.hasAttribute("background") ) setBackground( root.attribute("background") );
+    if( m_subcType >= Board ) setTransformOriginPoint( toGrid( boundingRect().center()) );
+    if( root.hasAttribute("name"))
+    {
+        QString name = root.attribute("name");
+        if( name.toLower() != "package" ) m_name = name;
+    }
+
     int chipPos = 0;
     QDomNode node = root.firstChild();
     while( !node.isNull() )
@@ -165,6 +163,7 @@ void Chip::initPackage( QDomElement root )
         }
         node = node.nextSibling();
     }
+    setName( m_name );
     update();
 }
 
@@ -232,24 +231,31 @@ void Chip::setBackground( QString bck )
         m_color = QColor( rgb.at(0).toInt(), rgb.at(1).toInt(), rgb.at(2).toInt() );
     }
     else if( bck != "" ){
-        QString pixmapPath = MainWindow::self()->getFilePath("data/images")+"/"+bck;
-        if( QFile::exists( pixmapPath ) )              // Image in simulide data folder
-            m_backPixmap = new QPixmap( pixmapPath );
-        else                                           // Image in Circuit data folder
-        {
-            QDir    circuitDir = QFileInfo( Circuit::self()->getFilePath() ).absoluteDir();
-            QString pixmapPath = circuitDir.absoluteFilePath( "data/"+m_name+"/"+bck );
-            if( QFile::exists( pixmapPath ) ) m_backPixmap = new QPixmap( pixmapPath );
+        QDir dir = QFileInfo( m_pkgeFile ).absoluteDir();
+        QString pixmapPath = dir.absoluteFilePath( bck );  // Image in subcircuit folder
+
+        if( !QFile::exists( pixmapPath ) ){
+            dir = QFileInfo( Circuit::self()->getFilePath() ).absoluteDir();
+            pixmapPath = dir.absoluteFilePath( bck );    // Image in circuit/data folder
         }
+        if( !QFile::exists( pixmapPath ) ) pixmapPath = MainWindow::self()->getDataFilePath("images/"+bck );
+        if( QFile::exists( pixmapPath ) ) m_backPixmap = new QPixmap( pixmapPath );
     }
     update();
 }
 
-void Chip::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget )
+void Chip::findHelp()
 {
-    Component::paint( p, option, widget );
+    QString helpFile = changeExt( m_dataFile, "txt" );
+    if( QFileInfo::exists( helpFile ) ) m_help = fileToString( helpFile, "Chip::findHelp" );
+    else                                m_help = MainWindow::self()->getHelp( m_name, false );
+}
 
-    if( m_backPixmap ) p->drawPixmap( m_area.x(), m_area.y(),m_width*8, m_height*8, *m_backPixmap );
+void Chip::paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w )
+{
+    Component::paint( p, o, w );
+
+    if( m_backPixmap ) p->drawPixmap( QRect(m_area.x(), m_area.y(), m_width*8, m_height*8), *m_backPixmap );
     else{
         p->drawRoundedRect( m_area, 1, 1);
         if( m_backData  )
@@ -261,9 +267,14 @@ void Chip::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget*
             p->drawRoundedRect( mW, mH, w, h, 1, 1);
             p->drawImage( mW, +mH, *m_backImage ); // Image centered*/
 
-            for( int x=0; x<m_width; x++ )
-                for( int y=0; y<m_height; y++ )
-                    p->fillRect( x, y, 1, 1, QColor(m_backData->at(x).at(y) ) );
+            int w = m_backData->size();
+            int h = m_backData->at(0).size();
+            int mW = m_area.x()+(m_width*8 - w)/2;
+            int mH = m_area.y()+(m_height*8 - h)/2;
+
+            for( int x=0; x<w; x++ )
+                for( int y=0; y<h; y++ )
+                    p->fillRect( QRectF( mW+x, mH+y, 1, 1), QColor(m_backData->at(x).at(y) ) );
         }
         else if( !m_isLS && m_background.isEmpty() )
         {
@@ -272,4 +283,5 @@ void Chip::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget*
             else                      p->drawArc( boundingRect().width()/2-6, -4, 8, 8, 0, -2880 /* -16*180 */ );
         }
     }
+    Component::paintSelected( p );
 }
