@@ -19,9 +19,10 @@ class InfoWidget : public QWidget, private Ui::infoWidget
 
  static InfoWidget* self() { return m_pSelf; }
 
-        void setRate( double rate=0, double simLoad=0, double guiLoad=0 );
+        void setRate( double rate=0, double simLoad=0, double guiLoad=0, int fps=0 );
         void setCircTime( uint64_t tStep );
         void setTargetSpeed( double s );
+        void updtMcu();
 
     public slots:
 
