@@ -12,7 +12,7 @@ class Component;
 class McuPort;
 class eMcu;
 
-class MAINMODULE_EXPORT AvrPin : public McuPin
+class AvrPin : public McuPin
 {
     friend class McuPort;
 
@@ -21,6 +21,7 @@ class MAINMODULE_EXPORT AvrPin : public McuPin
         ~AvrPin();
 
         virtual void setPortState( bool state ) override;
+        virtual void ConfExtInt( uint8_t bits ) override;
 
     protected:
 
