@@ -22,6 +22,7 @@
 #include "simulator.h"
 #include "itemlibrary.h"
 #include "circuitwidget.h"
+#include "infowidget.h"
 #include "mainwindow.h"
 #include "componentselector.h"
 #include "mcumonitor.h"
@@ -30,7 +31,6 @@
 #include "mcuintosc.h"
 #include "utils.h"
 #include "watcher.h"
-#include "linkable.h"
 
 #include "stringprop.h"
 #include "doubleprop.h"
@@ -79,7 +79,8 @@ Mcu::Mcu( QString type, QString id )
     addPropGroup( { tr("Main"), {},0} );
 
     m_device = m_name;//.split("_").last(); // for example: "atmega328-1" to: "atmega328"
-    if( m_device.contains("_") ) m_device = m_device.split("_").last(); // MCU in Subcircuit
+    if     ( m_device.contains("@") ) m_device = m_device.split("@").last(); // MCU in Subcircuit
+    else if( m_device.contains("_") ) m_device = m_device.split("_").last(); // MCU in Subcircuit Old
 
     if( m_device.startsWith("p") ) // PICs TODELETE
     {
@@ -96,7 +97,7 @@ Mcu::Mcu( QString type, QString id )
     m_autoLoad = false;
     m_scripted = false;
     m_resetPol = false;
-    m_linkable = true;
+    m_linker   = true;
 
     m_serialMon = -1;
 
@@ -165,6 +166,12 @@ Mcu::Mcu( QString type, QString id )
 
         QFile dataFile( m_dataFile );
         QFile pkgeFile( m_pkgeFile );
+        if( !pkgeFile.exists() )   // Check if package file exist, if not try LS or no LS
+        {
+            if     ( m_pkgeFile.endsWith("_LS.package")) m_pkgeFile.replace( "_LS.package", ".package" );
+            else if( m_pkgeFile.endsWith(".package"))    m_pkgeFile.replace( ".package", "_LS.package" );
+            pkgeFile.setFileName( m_pkgeFile );
+        }
         if( !dataFile.exists() || !pkgeFile.exists() )
         {
             MessageBoxNB( "Mcu::Mcu", "                               \n"+
@@ -243,7 +250,8 @@ if( hi.propList.size() > 0 ) addPropGroup( hi );
 Mcu::~Mcu()
 {
     if( m_mcuMonitor ) delete m_mcuMonitor;
-    if( m_pSelf == this ) m_pSelf= NULL;
+    if( m_pSelf == this ) m_pSelf = NULL;
+    InfoWidget::self()->updtMcu();
 }
 
 bool Mcu::setPropStr( QString prop, QString val )
@@ -262,6 +270,8 @@ void Mcu::initialize()
 
 void Mcu::stamp()
 {
+    m_eMcu.reset();
+
     if( m_resetPin ){
         m_resetPin->changeCallBack( this );
 
@@ -270,9 +280,11 @@ void Mcu::stamp()
             m_portRstPin->controlPin( true, true );
             m_portRstPin->setPinMode( input );
         }
-        m_resetPin->warning( !m_resetPin->connector() );
+        bool resetWarning = !m_resetPin->isConnected();
+        m_resetPin->warning( resetWarning );
+        if( resetWarning ) qDebug() << "    Warning!!"<<idLabel()<<"Reset pin not connected:\n";
     }
-    else m_eMcu.hardReset( false );
+    else m_eMcu.start();
 
     if( m_autoLoad )
     { if( !m_eMcu.m_firmware.isEmpty() ) load( m_eMcu.m_firmware ); }
@@ -432,9 +444,12 @@ bool Mcu::load( QString fileName )
         return false;
 
     for( int i=0; i<size; ++i ) m_eMcu.setFlashValue( i, pgm.at(i) );
-    qDebug() << "Firmware succesfully loaded\n";
+    qDebug() << "Firmware successfully loaded\n";
+
+    QString firmware = circuitDir.relativeFilePath( cleanPathAbs );
+    if( m_eMcu.m_firmware != firmware ) Circuit::self()->setChanged();
+    m_eMcu.m_firmware = firmware;
 
-    m_eMcu.m_firmware = circuitDir.relativeFilePath( cleanPathAbs );
     m_lastFirmDir = QFileInfo( cleanPathAbs ).absolutePath();
     if( m_propDialog ) m_propDialog->updtValues();
 
@@ -444,7 +459,7 @@ bool Mcu::load( QString fileName )
     return true;
 }
 
-void Mcu::contextMenuEvent( QGraphicsSceneContextMenuEvent* event )
+/*void Mcu::contextMenuEvent( QGraphicsSceneContextMenuEvent* event )
 {
     if( !acceptedMouseButtons() ) event->ignore();
     else{
@@ -453,15 +468,15 @@ void Mcu::contextMenuEvent( QGraphicsSceneContextMenuEvent* event )
         contextMenu( event, menu );
         Component::contextMenu( event, menu );
         menu->deleteLater();
-}   }
+}   }*/
 
-void Mcu::contextMenu( QGraphicsSceneContextMenuEvent*, QMenu* menu )
+void Mcu::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu )
 {
     QAction* mainAction = menu->addAction( QIcon(":/subc.png"),tr("Main Mcu") );
     QObject::connect( mainAction, &QAction::triggered
                       , [=](){ slotmain(); } );
 
-    if( m_scriptLink )
+    if( m_scriptLink && !parentItem() )
     {
         QAction* linkCompAction = menu->addAction( QIcon(":/subcl.png"),tr("Link to Component") );
         QObject::connect( linkCompAction, &QAction::triggered, [=](){ slotLinkComp(); } );
@@ -505,33 +520,32 @@ void Mcu::contextMenu( QGraphicsSceneContextMenuEvent*, QMenu* menu )
         QObject::connect( sm, QOverload<int>::of(&QSignalMapper::mapped), [=](int n){ slotOpenTerm(n);} );
     }
     menu->addSeparator();
+    Component::contextMenu( event, menu );
 }
 
 void Mcu::slotmain()
 {
     m_pSelf = this;
     m_eMcu.setMain();
+    InfoWidget::self()->updtMcu();
     Circuit::self()->update();
 }
 
 void Mcu::slotLinkComp()
 {
-    Linkable::startLinking();
+    Linker::startLinking();
 }
 
 void Mcu::slotOpenMcuMonitor()
 {
-    if( !m_mcuMonitor )
-    {
-        m_mcuMonitor = new MCUMonitor( CircuitWidget::self(), &m_eMcu );
-        m_mcuMonitor->setWindowTitle( idLabel() );
-    }
+    if( !m_mcuMonitor ) m_mcuMonitor = new MCUMonitor( CircuitWidget::self(), &m_eMcu );
+    m_mcuMonitor->setWindowTitle( findIdLabel() );
     m_mcuMonitor->show();
 }
 
 void Mcu::slotOpenTerm( int num )
 {
-    m_eMcu.m_usarts.at(num-1)->openMonitor( idLabel(), num );
+    m_eMcu.m_usarts.at(num-1)->openMonitor( findIdLabel(), num );
     m_serialMon = num;
 }
 
@@ -544,6 +558,16 @@ int Mcu::serialMon()
 
 void Mcu::setSerialMon( int s ) { if( s>=0 ) slotOpenTerm( s ); }
 
+QString Mcu::findIdLabel() /// FIXME: move to Component??
+{
+    QString label = idLabel();
+    if( this->parentItem() ){
+        Component* comp = qgraphicsitem_cast<Component*>( this->parentItem() );
+        label = comp->idLabel();
+    }
+    return label;
+}
+
 void Mcu::setLinkedValue( double v, int i )
 {
     if( m_scriptLink ) m_scriptLink->setLinkedVal( v, i );
@@ -595,7 +619,7 @@ bool Mcu::rstPinEnabled()
     return (m_resetPin == m_portRstPin);
 }
 
-void Mcu::enableRstPin( bool en )
+void Mcu::enableRstPin( bool en ) // Called from Property or cfg word
 {
     if( !m_portRstPin ) return;
 
