@@ -8,7 +8,7 @@
 
 #include "e-resistor.h"
 
-class MAINMODULE_EXPORT eMosfet : public eResistor
+class eMosfet : public eResistor
 {
     public:
         eMosfet( QString id );
@@ -18,10 +18,10 @@ class MAINMODULE_EXPORT eMosfet : public eResistor
         virtual void voltChanged() override;
 
         bool pChannel() { return m_Pchannel; }
-        void setPchannel( bool p ) { m_Pchannel = p; m_changed = true; }
+        virtual void setPchannel( bool p ) { m_Pchannel = p; m_changed = true; }
 
         bool depletion() { return m_depletion; }
-        void setDepletion( bool d ) { m_depletion = d; m_changed = true; }
+        virtual void setDepletion( bool d ) { m_depletion = d; m_changed = true; }
 
         double rdson() { return m_RDSon; }
         void setRDSon( double rdson );
@@ -30,6 +30,8 @@ class MAINMODULE_EXPORT eMosfet : public eResistor
         void setThreshold( double th );
         
     protected:
+        void updateValues();
+
         double m_accuracy;
         double m_lastCurrent;
         double m_threshold;
